@@ -1,5 +1,3 @@
-from __future__ import print_function
-from os.path import isfile
 from irff.irff_np import IRFF_NP
 from ase.io import read,write
 from ase.io.trajectory import TrajectoryWriter
@@ -39,7 +37,7 @@ def getBonds(natom,r,rcut,bo,botol=0.0):
 
 
 class AtomDance(object):
-  def __init__(self,atoms=None,poscar=None,nn=True,rtole=0.5,bondTole=1.25,botol=0.0):
+  def __init__(self,atoms=None,poscar=None,nn=True,rtole=0.4,bondTole=1.25,botol=0.0):
       self.rtole         = rtole
       self.bondTole      = bondTole
       self.botol         = botol
@@ -158,15 +156,15 @@ class AtomDance(object):
       if not bondTole is None:
          self.bondTole = bondTole
       self.ir.calculate_Delta(atoms,updateP=True)
+
       bkbd       = None
       bB_        = 0
-      
       bondBroken = False
       bondTole_  = self.bondTole - 0.015
       bonds      = getBonds(self.natom,self.ir.r,bondTole_*self.ir.re,
                             self.ir.bo0,botol=self.botol*0.5)
       
-      if len(bonds) == len(self.InitBonds):
+      if len(bonds) >= len(self.InitBonds):
          for bd in self.InitBonds:
              bd_ = (bd[1],bd[0])
              if (bd not in bonds) and (bd_ not in bonds):
@@ -175,6 +173,11 @@ class AtomDance(object):
                 break
       else:
          bondBroken = True
+         for bd in self.InitBonds:
+             bd_ = (bd[1],bd[0])
+             if (bd not in bonds) and (bd_ not in bonds):
+                bkbd = bd
+                break
       if bondBroken:
          bB_ += 1
 
@@ -182,14 +185,13 @@ class AtomDance(object):
       bondTole_  = self.bondTole  
       bonds      = getBonds(self.natom,self.ir.r,bondTole_*self.ir.re,
                             self.ir.bo0,botol=self.botol)
-      if len(bonds) == len(self.InitBonds):
+      if len(bonds) >= len(self.InitBonds):
          for bd in self.InitBonds:
              bd_ = (bd[1],bd[0])
-             if (bd not in bonds) and (bd_ not in bonds):
-                bondBroken = True
-                break
       else:
          bondBroken = True
+         for bd in self.InitBonds:
+             bd_ = (bd[1],bd[0])
       if bondBroken:
          bB_ += 1
       return bB_,bkbd
@@ -469,6 +471,7 @@ class AtomDance(object):
           self.ir.calculate(atoms_)
           i_= np.where(np.logical_and(self.ir.r<self.ir.re[i][j]*self.rtole-bin_,self.ir.r>0.0001))
           n = len(i_[0])
+
           try:
              assert n==0,'Atoms too closed!'
           except:
