@@ -3,6 +3,7 @@ from os.path import exists,isfile
 from os import getcwd,chdir,mkdir,listdir,popen #,system,
 from ase.io import read,write
 from ase.io.trajectory import Trajectory
+from ase.constraints import FixAtoms
 import matplotlib.pyplot as plt
 from math import ceil
 from .molecule import packmol
@@ -158,12 +159,17 @@ class LearningMachine(object):
       self.bo_penalty   = bo_penalty
       self.EnergyFunction = EnergyFunction
       self.MessageFunction= MessageFunction
-      self.FreeAtoms    = FreeAtoms
+      self.freeatoms    = FreeAtoms
       self.c            = AtomDance(poscar=self.initConfig,nn=self.nn,
                                     rtole=self.rtole-0.05,bondTole=self.bondTole)
       self.natom        = self.c.natom
       self.atom_name    = self.c.atom_name
       self.get_ro(rodic)
+      atoms             = self.c.ir.atoms
+      if FreeAtoms is None:
+         self.fixatoms  = None
+      else:
+         self.fixatoms  = FixAtoms(indices=[atom.index for atom in atoms if atom.index not in FreeAtoms])
 
       if self.mpopt==1:
          self.messages  = 1
@@ -234,9 +240,11 @@ class LearningMachine(object):
 
           if isfile('md.traj'): 
              atoms = read('md.traj',index=-1)
+             atoms.set_constraint(self.fixatoms)
           else:
              atoms = read(self.initConfig)
              atoms = self.c.bond_momenta_bigest(atoms)
+             atoms.set_constraint(self.fixatoms)
              e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,10000,i,learnWay) 
  
           if learnWay==4 and lw4:
@@ -390,7 +398,7 @@ class LearningMachine(object):
 
       if learnWay<=2:
          images = siesta_md(label=self.label,ncpu=self.ncpu,T=self.T,dt=self.dt_aimd,us='F',tstep=tstep,
-                            gen=cwd+'/'+gen,FreeAtoms=self.FreeAtoms,
+                            gen=cwd+'/'+gen,FreeAtoms=self.freeatoms,
                             xcf=self.xcf,xca=self.xca,basistype=self.basistype)
          eaimd = [images[0].get_potential_energy()]
       elif learnWay>=3:
