@@ -12,7 +12,7 @@ class DLAM(object):
   def __init__(self):
       ''' fake DingtalkChatbot ''' 
 
-  def send_markdown(title='Master:',text=' '):
+  def send_markdown(self,title='Master:',text=' '):
       print(' * ',title)
       print(' ')
       print('------------------------------------')
@@ -52,9 +52,9 @@ def send_msg(msg):
     # msg += '\n\n----------------\n'
     # msg += '\n From: '+hostname+'@'+ip+'\n' #\nmy master
     msg += '\n (directory: '+cwd+')'
-    try:
-       dlam.send_markdown(title='Master:',text=msg)
-    except:
-       # send_mail(msg)
-       print('-  warning massage send failed.')
+    # try:
+    dlam.send_markdown(title='Master:',text=msg)
+    # except:
+    # send_mail(msg)
+    # print('-  warning massage send failed.')
 
