@@ -80,17 +80,18 @@ class IRFF(Calculator):
   name = "IRFF"
   implemented_properties = ["energy", "forces", "stress","pressure"]
   def __init__(self,atoms=None,
-              libfile='ffield',
-              rcut=None,rcuta=None,
-              vdwcut=10.0,
-              atol=0.001,
-              hbtol=0.001,
-              nn=False,vdwnn=False,
-              messages=1,
-              hbshort=6.75,hblong=7.5,
-              autograd=True,
-              CalStress=False,
-              label="IRFF", **kwargs):
+               mol=None,
+               libfile='ffield',
+               rcut=None,rcuta=None,
+               vdwcut=10.0,
+               atol=0.001,
+               hbtol=0.001,
+               nn=False,vdwnn=False,
+               messages=1,
+               hbshort=6.75,hblong=7.5,
+               autograd=True,
+               CalStress=False,
+               label="IRFF", **kwargs):
       Calculator.__init__(self,label=label, **kwargs)
       self.atoms        = atoms
       self.cell         = atoms.get_cell()
@@ -121,11 +122,21 @@ class IRFF(Calculator):
          self.vdw_layer      = j['vdw_layer']
          lf.close()
          self.init_bonds()
+         if mol is None:
+            self.emol = 0.0
+         else:
+            mol_ = mol.split('-')[0]
+            if mol_ in self.MolEnergy_:
+               self.emol = self.MolEnergy_[mol_]
+            else:
+               self.emol = 0.0
+            
       else:
          self.p,zpe_,self.spec,self.bonds,self.offd,self.angs,self.torp,self.Hbs= \
                        read_lib(libfile=libfile,zpe=False)
          m             = None
          self.bo_layer = None
+         self.emol      = 0.0
 
       if m is None:
          self.nn=False
@@ -1040,7 +1051,7 @@ class IRFF(Calculator):
                 self.P[key][i] = self.p[key+'_'+sp]*unit_
           self.P[key] = torch.tensor(self.P[key])
 
-      self.zpe = -torch.sum(self.P['atomic'])
+      self.zpe = -torch.sum(self.P['atomic']) + self.emol
 
 
       for key in ['boc3','boc4','boc5','gamma','gammaw']:
